# Set Up

## Dataset

Download
https://www.nltk.org/nltk_data/ The Reuters-21578 benchmark corpus
https://www.gutenberg.org/cache/epub/feeds/ The Project Gutenberg offline catalog


## Benchmark Script

Set the local path for data on the top of script

```bash
# run gutenberg sample
python benchmark/gutenberg.py -n 100 

# run reuter data
python benchmark/reuters.py
```
